/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.console.GWTConsole.client.Commons;

import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.user.client.ui.Image;

/**
 * This class defines an ActionImage. An action image is an image used as a button to trigger
 * action in the actions column of several grid. 
 * 
 * @author Mathieu Crassin
 * 
 */
public class ActionImage extends Image {
  
  /**
   * Position of the action in the grid
   * 
   * @author Mathieu Crassin
   * 
   */
  private int rowIndex;
  
  
  /** 
   * Boolean to know if the action is enabled or not. Different images are used to display the different states. 
   * 
   * @author Mathieu Crassin
   * 
   */
  private boolean enabled = true;
  
  
  /**
   * The 2 images, when enabled and not.
   * 
   * @author Mathieu Crassin
   * 
   */
  private ImageResource activeImage, inactiveImage;
  
  
  /**
   * Constructor of the class.
   * 
   * @param activeImage : Image that represent the action when active
   * @param inactiveImage : Image that represent the action when inactive
   * @param rowIndex : The row number in the grid.
   */
  public ActionImage(ImageResource activeImage, ImageResource inactiveImage, int rowIndex) {
    super(activeImage);
    //
    this.activeImage = activeImage;
    this.inactiveImage = inactiveImage;
    //
    this.enabled = true;
    this.rowIndex = rowIndex;
    //
    this.display();
  }

  /**
   * Change ImageAction state.
   * 
   * @author Mathieu Crassin
   * @param enable : new state
   * 
   */
  public void setEnabled(boolean enable) { 
    // change state
    this.enabled = enable;
    // update image
    display();
  }
  
  
  /**
   * Display our ActionImage
   * 
   * @author Mathieu Crassin
   * 
   */
  public void display() {
    if (enabled) {
      this.setResource(activeImage);
    } else {
      this.setResource(inactiveImage);
    }
  }
  
  
  /**
   * Get method of RowIndex object.
   * 
   * @author Mathieu Crassin
   * @return int : the index of the image's row
   * 
   */
  public int getRowIndex() {
    return this.rowIndex;
  }
  
  /**
   * Define the ActionImage handler.
   * 
   * @author Mathieu Crassin
   * @param action : the action class
   * 
   */
  public void setHandler(final ActionClass action) {
    // add click handler on active image
    this.addClickHandler(new ClickHandler() {
      
      public void onClick(ClickEvent arg0) {
        if (enabled) {
          action.execute(); 
        } else {
          System.out.println("click handler of ActionImage, state inactive"); 
        }
      }
    });    
  }  
}
