/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.console.GWTConsole.client.Commons;

import com.google.gwt.user.client.ui.Label;


/**
 * This class is used to store the id of element (process, instance, activity) in the label class to avoid parsing the label
 * 
 * @author Jean-Yves Goubet
 *
 */
public class IdLabel extends Label {
  
  // it's the id of the element
  private String id = null;
  
  // it's the name of the element (used for tab creation)
  private String name = null;
  
  // it's the row of the label
  private int row = -1;
  
  // it's the column of the label
  private int column = -1;
  
  
  /**
   * Constructor of the class
   * 
   * @author Jean-Yves Goubet
   * @param text : the text of the label
   * @param id : the element id
   * @param name : the element name
   * @param row : the row of the label
   * @param column : the column of the label
   * 
   */
  public IdLabel(String text, String id, String name, int row, int column) {
    super(text);
    this.id = id;
    this.name = name;
    this.row = row;
    this.column = column;
  }
  
  
  /**
   * Getter of the id parameter
   * 
   * @author Jean-Yves Goubet
   * @return String : the id parameter
   * 
   */
  public String getId() {
    return this.id;
  }
  
  
  /**
   * Getter of the name parameter
   * 
   * @author Jean-Yves Goubet
   * @return String : the name parameter
   * 
   */
  public String getName() {
    return this.name;
  }
  
  
  /**
   * Getter of the row parameter
   * 
   * @author Jean-Yves Goubet
   * @return String : the row parameter
   * 
   */
  public int getRow() {
    return this.row;
  }
  
  
  /**
   * Getter of the column parameter
   * 
   * @author Jean-Yves Goubet
   * @return String : the column parameter
   * 
   */
  public int getColumn() {
    return this.column;
  }
}
