/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.console.GWTConsole.client.LoginPanel;

import org.ow2.orchestra.console.GWTConsole.client.Commons.PresenterIF;

import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Widget;


/**
 * This class is the presenter of the panel used for the login page.
 * 
 * @author Jean-Yves Goubet
 *
 */
public class PLoginPanel extends PresenterIF {

  private VLoginPanelIF view;
  
  public PLoginPanel() {
    //
    VLoginPanelIF view = new VLoginPanel();
    this.bindingView(view);
    
    //
    this.setDebugID();
    
    //
    this.manageError();
  }
  
  /**
   * This method is used to hide or show the log failed message depending on the Href
   * 
   * @author Jean-Yves Goubet
   * 
   */
  private void manageError() {
    if (Window.Location.getHref().contains("j_security_check")) {
      this.view.getLogFailedLabel().setVisible(true);
    } else {
      this.view.getLogFailedLabel().setVisible(false);
    }
  }


  protected void bindingView(final Object view) {
    this.view = (VLoginPanelIF) view;
  }
  
  /**
   * Define an id for each widget. 
   * This Id is used by selenium for the integration tests phase.
   * 
   * @author Mathieu Crassin
   *
   */  
  protected void setDebugID() {
    this.view.getFormPanel().ensureDebugId("loginFormPanelId");
    this.view.getUserNameField().ensureDebugId("userNameFieldId");
    this.view.getPasswordField().ensureDebugId("passwordFieldId");
    this.view.getLogFailedLabel().ensureDebugId("logFailedLabelId");
    this.view.getSubmitButton().ensureDebugId("submitButtonId");
  }

  
  /**
   * 
   * @return
   */
  public Widget getView() {
    return (Widget) this.view;
  }

  protected void addListeners() {
    // no listeners
    
  }
  public void destroy() {
    // no operations on destroy
    
  }    
  
}
